import { z } from 'zod/v4';
declare const service: {
    name: string;
    slug: string;
    description: string;
    hasPublicEndpoints: boolean;
    endpoints: ({
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    task: z.ZodString;
                    label: z.ZodOptional<z.ZodString>;
                    agent: z.ZodOptional<z.ZodString>;
                    defaultAgent: z.ZodOptional<z.ZodString>;
                    visibility: z.ZodOptional<z.ZodEnum<{
                        private: "private";
                        organization: "organization";
                        collaborate: "collaborate";
                    }>>;
                    workflowMode: z.ZodOptional<z.ZodEnum<{
                        standard: "standard";
                        loop: "loop";
                    }>>;
                    loop: z.ZodOptional<z.ZodObject<{
                        goal: z.ZodOptional<z.ZodString>;
                        maxIterations: z.ZodOptional<z.ZodNumber>;
                        autoContinue: z.ZodOptional<z.ZodBoolean>;
                        allowDetached: z.ZodOptional<z.ZodBoolean>;
                    }, z.core.$strip>>;
                    tags: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    enabledAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    skillBucketIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    skills: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        skillId: z.ZodString;
                        repo: z.ZodString;
                        name: z.ZodOptional<z.ZodString>;
                        url: z.ZodOptional<z.ZodString>;
                        content: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>>;
                    repo: z.ZodOptional<z.ZodObject<{
                        repoId: z.ZodOptional<z.ZodString>;
                        type: z.ZodOptional<z.ZodString>;
                        provider: z.ZodOptional<z.ZodString>;
                        owner: z.ZodOptional<z.ZodString>;
                        name: z.ZodOptional<z.ZodString>;
                        fullName: z.ZodOptional<z.ZodString>;
                        url: z.ZodOptional<z.ZodString>;
                        cloneUrl: z.ZodOptional<z.ZodString>;
                        defaultBranch: z.ZodOptional<z.ZodString>;
                        branch: z.ZodOptional<z.ZodString>;
                        ref: z.ZodOptional<z.ZodString>;
                        commit: z.ZodOptional<z.ZodString>;
                        path: z.ZodOptional<z.ZodString>;
                        rootPath: z.ZodOptional<z.ZodString>;
                    }, z.core.$catchall<z.ZodUnknown>>>;
                    repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        repoId: z.ZodOptional<z.ZodString>;
                        type: z.ZodOptional<z.ZodString>;
                        provider: z.ZodOptional<z.ZodString>;
                        owner: z.ZodOptional<z.ZodString>;
                        name: z.ZodOptional<z.ZodString>;
                        fullName: z.ZodOptional<z.ZodString>;
                        url: z.ZodOptional<z.ZodString>;
                        cloneUrl: z.ZodOptional<z.ZodString>;
                        defaultBranch: z.ZodOptional<z.ZodString>;
                        branch: z.ZodOptional<z.ZodString>;
                        ref: z.ZodOptional<z.ZodString>;
                        commit: z.ZodOptional<z.ZodString>;
                        path: z.ZodOptional<z.ZodString>;
                        rootPath: z.ZodOptional<z.ZodString>;
                    }, z.core.$catchall<z.ZodUnknown>>>>;
                    workspaceId: z.ZodOptional<z.ZodString>;
                    projectId: z.ZodOptional<z.ZodString>;
                    runtime: z.ZodOptional<z.ZodString>;
                    runtimeId: z.ZodOptional<z.ZodString>;
                    name: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodString>;
                    resources: z.ZodOptional<z.ZodObject<{
                        memory: z.ZodOptional<z.ZodString>;
                        cpu: z.ZodOptional<z.ZodString>;
                        disk: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>;
                    env: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    network: z.ZodOptional<z.ZodObject<{
                        enabled: z.ZodOptional<z.ZodBoolean>;
                        port: z.ZodOptional<z.ZodNumber>;
                    }, z.core.$strip>>;
                    stream: z.ZodOptional<z.ZodObject<{
                        stdout: z.ZodOptional<z.ZodString>;
                        stderr: z.ZodOptional<z.ZodString>;
                        stdin: z.ZodOptional<z.ZodString>;
                        timestamps: z.ZodOptional<z.ZodBoolean>;
                    }, z.core.$strip>>;
                    timeout: z.ZodOptional<z.ZodObject<{
                        idle: z.ZodOptional<z.ZodString>;
                        execution: z.ZodOptional<z.ZodString>;
                        paused: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>;
                    command: z.ZodOptional<z.ZodObject<{
                        exec: z.ZodArray<z.ZodString>;
                        files: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            path: z.ZodString;
                            content: z.ZodCustom<Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>>;
                        }, z.core.$strip>>>;
                        mode: z.ZodOptional<z.ZodEnum<{
                            oneshot: "oneshot";
                            interactive: "interactive";
                        }>>;
                    }, z.core.$strip>>;
                    files: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        path: z.ZodString;
                        content: z.ZodCustom<Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>>;
                    }, z.core.$strip>>>;
                    snapshot: z.ZodOptional<z.ZodString>;
                    dependencies: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    packages: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    scopes: z.ZodOptional<z.ZodArray<z.ZodString>>;
                }, z.core.$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                sessionId: z.ZodString;
                sandboxId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
                status: z.ZodString;
                mode: z.ZodOptional<z.ZodString>;
                visibility: z.ZodOptional<z.ZodString>;
            }, z.core.$loose>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            task: string;
            workflowMode: string;
            mode?: undefined;
            sourceSessionId?: undefined;
            label?: undefined;
            prompt?: undefined;
            tags?: undefined;
            slug?: undefined;
            displayName?: undefined;
            instructions?: undefined;
            tools?: undefined;
            serviceTools?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    label: z.ZodOptional<z.ZodString>;
                    prompt: z.ZodOptional<z.ZodString>;
                    mode: z.ZodOptional<z.ZodEnum<{
                        edit: "edit";
                        new: "new";
                        from_session: "from_session";
                    }>>;
                    visibility: z.ZodOptional<z.ZodEnum<{
                        private: "private";
                        organization: "organization";
                        collaborate: "collaborate";
                    }>>;
                    sourceSessionId: z.ZodOptional<z.ZodString>;
                    targetAgentId: z.ZodOptional<z.ZodString>;
                    targetAgentSlug: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                sessionId: z.ZodString;
                sandboxId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
                status: z.ZodString;
                mode: z.ZodOptional<z.ZodString>;
                visibility: z.ZodOptional<z.ZodString>;
            }, z.core.$loose>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            mode: string;
            sourceSessionId: string;
            label: string;
            prompt: string;
            task?: undefined;
            workflowMode?: undefined;
            tags?: undefined;
            slug?: undefined;
            displayName?: undefined;
            instructions?: undefined;
            tools?: undefined;
            serviceTools?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                sessions: z.ZodObject<{
                    websocket: z.ZodArray<z.ZodObject<{
                        sessionId: z.ZodString;
                        label: z.ZodString;
                        status: z.ZodString;
                        mode: z.ZodEnum<{
                            sandbox: "sandbox";
                            tui: "tui";
                        }>;
                        visibility: z.ZodString;
                        owner: z.ZodOptional<z.ZodObject<{
                            userId: z.ZodString;
                            name: z.ZodOptional<z.ZodString>;
                        }, z.core.$strip>>;
                        origin: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodObject<{
                            type: z.ZodString;
                        }, z.core.$catchall<z.ZodUnknown>>]>>;
                        repo: z.ZodOptional<z.ZodObject<{
                            repoId: z.ZodOptional<z.ZodString>;
                            type: z.ZodOptional<z.ZodString>;
                            provider: z.ZodOptional<z.ZodString>;
                            owner: z.ZodOptional<z.ZodString>;
                            name: z.ZodOptional<z.ZodString>;
                            fullName: z.ZodOptional<z.ZodString>;
                            url: z.ZodOptional<z.ZodString>;
                            cloneUrl: z.ZodOptional<z.ZodString>;
                            defaultBranch: z.ZodOptional<z.ZodString>;
                            branch: z.ZodOptional<z.ZodString>;
                            ref: z.ZodOptional<z.ZodString>;
                            commit: z.ZodOptional<z.ZodString>;
                            path: z.ZodOptional<z.ZodString>;
                            rootPath: z.ZodOptional<z.ZodString>;
                        }, z.core.$catchall<z.ZodUnknown>>>;
                        repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            repoId: z.ZodOptional<z.ZodString>;
                            type: z.ZodOptional<z.ZodString>;
                            provider: z.ZodOptional<z.ZodString>;
                            owner: z.ZodOptional<z.ZodString>;
                            name: z.ZodOptional<z.ZodString>;
                            fullName: z.ZodOptional<z.ZodString>;
                            url: z.ZodOptional<z.ZodString>;
                            cloneUrl: z.ZodOptional<z.ZodString>;
                            defaultBranch: z.ZodOptional<z.ZodString>;
                            branch: z.ZodOptional<z.ZodString>;
                            ref: z.ZodOptional<z.ZodString>;
                            commit: z.ZodOptional<z.ZodString>;
                            path: z.ZodOptional<z.ZodString>;
                            rootPath: z.ZodOptional<z.ZodString>;
                        }, z.core.$catchall<z.ZodUnknown>>>>;
                        workspace: z.ZodOptional<z.ZodObject<{
                            id: z.ZodString;
                            name: z.ZodString;
                            scope: z.ZodEnum<{
                                org: "org";
                                user: "user";
                            }>;
                        }, z.core.$strip>>;
                        sessionKind: z.ZodOptional<z.ZodString>;
                        parentSessionId: z.ZodOptional<z.ZodString>;
                        coordinationJobId: z.ZodOptional<z.ZodString>;
                        workflowMode: z.ZodEnum<{
                            standard: "standard";
                            loop: "loop";
                        }>;
                        loopStatus: z.ZodOptional<z.ZodString>;
                        loopIteration: z.ZodOptional<z.ZodNumber>;
                        createdAt: z.ZodString;
                        lastActivityAt: z.ZodString;
                        taskCount: z.ZodNumber;
                        subAgentCount: z.ZodNumber;
                        observerCount: z.ZodNumber;
                        participantCount: z.ZodNumber;
                        tags: z.ZodArray<z.ZodString>;
                        skills: z.ZodArray<z.ZodObject<{
                            skillId: z.ZodString;
                            repo: z.ZodString;
                            name: z.ZodOptional<z.ZodString>;
                            url: z.ZodOptional<z.ZodString>;
                            content: z.ZodOptional<z.ZodString>;
                        }, z.core.$strip>>;
                        enabledAgents: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
                        builder: z.ZodOptional<z.ZodObject<{
                            mode: z.ZodEnum<{
                                edit: "edit";
                                new: "new";
                                from_session: "from_session";
                            }>;
                            sourceSession: z.ZodOptional<z.ZodObject<{
                                sessionId: z.ZodString;
                                label: z.ZodOptional<z.ZodString>;
                            }, z.core.$strip>>;
                            targetAgent: z.ZodOptional<z.ZodObject<{
                                agentId: z.ZodOptional<z.ZodString>;
                                slug: z.ZodString;
                                displayName: z.ZodOptional<z.ZodString>;
                            }, z.core.$strip>>;
                            durable: z.ZodOptional<z.ZodObject<{
                                draftAgentId: z.ZodOptional<z.ZodString>;
                                draftAgentSlug: z.ZodOptional<z.ZodString>;
                                lastPublishedVersion: z.ZodOptional<z.ZodNumber>;
                            }, z.core.$strip>>;
                            lastAction: z.ZodOptional<z.ZodObject<{
                                kind: z.ZodEnum<{
                                    create_draft: "create_draft";
                                    update_draft: "update_draft";
                                    publish: "publish";
                                }>;
                                status: z.ZodEnum<{
                                    completed: "completed";
                                    failed: "failed";
                                }>;
                                occurredAt: z.ZodString;
                                message: z.ZodOptional<z.ZodString>;
                                agentId: z.ZodOptional<z.ZodString>;
                                agentSlug: z.ZodOptional<z.ZodString>;
                                publishedVersion: z.ZodOptional<z.ZodNumber>;
                            }, z.core.$strip>>;
                        }, z.core.$strip>>;
                        defaultAgent: z.ZodOptional<z.ZodString>;
                        bucket: z.ZodEnum<{
                            running: "running";
                            paused: "paused";
                            provisioning: "provisioning";
                            history: "history";
                        }>;
                        runtimeAvailable: z.ZodBoolean;
                        controlAvailable: z.ZodBoolean;
                        manageAvailable: z.ZodOptional<z.ZodBoolean>;
                        wakeAvailable: z.ZodBoolean;
                        historyOnly: z.ZodBoolean;
                        liveExpected: z.ZodBoolean;
                    }, z.core.$strip>>;
                    sandbox: z.ZodArray<z.ZodUnknown>;
                }, z.core.$strip>;
                total: z.ZodNumber;
            }, z.core.$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                sessionId: z.ZodString;
                label: z.ZodString;
                status: z.ZodString;
                mode: z.ZodEnum<{
                    sandbox: "sandbox";
                    tui: "tui";
                }>;
                visibility: z.ZodString;
                owner: z.ZodOptional<z.ZodObject<{
                    userId: z.ZodString;
                    name: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>>;
                origin: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodObject<{
                    type: z.ZodString;
                }, z.core.$catchall<z.ZodUnknown>>]>>;
                repo: z.ZodOptional<z.ZodObject<{
                    repoId: z.ZodOptional<z.ZodString>;
                    type: z.ZodOptional<z.ZodString>;
                    provider: z.ZodOptional<z.ZodString>;
                    owner: z.ZodOptional<z.ZodString>;
                    name: z.ZodOptional<z.ZodString>;
                    fullName: z.ZodOptional<z.ZodString>;
                    url: z.ZodOptional<z.ZodString>;
                    cloneUrl: z.ZodOptional<z.ZodString>;
                    defaultBranch: z.ZodOptional<z.ZodString>;
                    branch: z.ZodOptional<z.ZodString>;
                    ref: z.ZodOptional<z.ZodString>;
                    commit: z.ZodOptional<z.ZodString>;
                    path: z.ZodOptional<z.ZodString>;
                    rootPath: z.ZodOptional<z.ZodString>;
                }, z.core.$catchall<z.ZodUnknown>>>;
                repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    repoId: z.ZodOptional<z.ZodString>;
                    type: z.ZodOptional<z.ZodString>;
                    provider: z.ZodOptional<z.ZodString>;
                    owner: z.ZodOptional<z.ZodString>;
                    name: z.ZodOptional<z.ZodString>;
                    fullName: z.ZodOptional<z.ZodString>;
                    url: z.ZodOptional<z.ZodString>;
                    cloneUrl: z.ZodOptional<z.ZodString>;
                    defaultBranch: z.ZodOptional<z.ZodString>;
                    branch: z.ZodOptional<z.ZodString>;
                    ref: z.ZodOptional<z.ZodString>;
                    commit: z.ZodOptional<z.ZodString>;
                    path: z.ZodOptional<z.ZodString>;
                    rootPath: z.ZodOptional<z.ZodString>;
                }, z.core.$catchall<z.ZodUnknown>>>>;
                workspace: z.ZodOptional<z.ZodObject<{
                    id: z.ZodString;
                    name: z.ZodString;
                    scope: z.ZodEnum<{
                        org: "org";
                        user: "user";
                    }>;
                }, z.core.$strip>>;
                sessionKind: z.ZodOptional<z.ZodString>;
                parentSessionId: z.ZodOptional<z.ZodString>;
                coordinationJobId: z.ZodOptional<z.ZodString>;
                workflowMode: z.ZodEnum<{
                    standard: "standard";
                    loop: "loop";
                }>;
                loopStatus: z.ZodOptional<z.ZodString>;
                loopIteration: z.ZodOptional<z.ZodNumber>;
                createdAt: z.ZodString;
                tags: z.ZodArray<z.ZodString>;
                skills: z.ZodArray<z.ZodObject<{
                    skillId: z.ZodString;
                    repo: z.ZodString;
                    name: z.ZodOptional<z.ZodString>;
                    url: z.ZodOptional<z.ZodString>;
                    content: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>>;
                enabledAgents: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
                defaultAgent: z.ZodOptional<z.ZodString>;
                bucket: z.ZodEnum<{
                    running: "running";
                    paused: "paused";
                    provisioning: "provisioning";
                    history: "history";
                }>;
                runtimeAvailable: z.ZodBoolean;
                controlAvailable: z.ZodBoolean;
                manageAvailable: z.ZodOptional<z.ZodBoolean>;
                wakeAvailable: z.ZodBoolean;
                historyOnly: z.ZodBoolean;
                liveExpected: z.ZodBoolean;
                task: z.ZodOptional<z.ZodString>;
                env: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                updatedAt: z.ZodOptional<z.ZodString>;
                builder: z.ZodOptional<z.ZodObject<{
                    mode: z.ZodEnum<{
                        edit: "edit";
                        new: "new";
                        from_session: "from_session";
                    }>;
                    sourceSession: z.ZodOptional<z.ZodObject<{
                        sessionId: z.ZodString;
                        label: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>;
                    targetAgent: z.ZodOptional<z.ZodObject<{
                        agentId: z.ZodOptional<z.ZodString>;
                        slug: z.ZodString;
                        displayName: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>;
                    durable: z.ZodOptional<z.ZodObject<{
                        draftAgentId: z.ZodOptional<z.ZodString>;
                        draftAgentSlug: z.ZodOptional<z.ZodString>;
                        lastPublishedVersion: z.ZodOptional<z.ZodNumber>;
                    }, z.core.$strip>>;
                    lastAction: z.ZodOptional<z.ZodObject<{
                        kind: z.ZodEnum<{
                            create_draft: "create_draft";
                            update_draft: "update_draft";
                            publish: "publish";
                        }>;
                        status: z.ZodEnum<{
                            completed: "completed";
                            failed: "failed";
                        }>;
                        occurredAt: z.ZodString;
                        message: z.ZodOptional<z.ZodString>;
                        agentId: z.ZodOptional<z.ZodString>;
                        agentSlug: z.ZodOptional<z.ZodString>;
                        publishedVersion: z.ZodOptional<z.ZodNumber>;
                    }, z.core.$strip>>;
                    proposal: z.ZodOptional<z.ZodObject<{
                        slug: z.ZodOptional<z.ZodString>;
                        displayName: z.ZodOptional<z.ZodString>;
                        description: z.ZodOptional<z.ZodString>;
                        instructions: z.ZodOptional<z.ZodString>;
                        model: z.ZodOptional<z.ZodString>;
                        thinkingLevel: z.ZodOptional<z.ZodEnum<{
                            off: "off";
                            minimal: "minimal";
                            low: "low";
                            medium: "medium";
                            high: "high";
                            xhigh: "xhigh";
                        }>>;
                        headlessCompatible: z.ZodOptional<z.ZodBoolean>;
                        tools: z.ZodDefault<z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                            read: "read";
                            ls: "ls";
                            find: "find";
                            grep: "grep";
                            bash: "bash";
                            write: "write";
                            edit: "edit";
                        }>, z.ZodString]>>>;
                        serviceTools: z.ZodDefault<z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                            session_dashboard: "session_dashboard";
                            memory_service_search: "memory_service_search";
                            memory_service_store: "memory_service_store";
                            memory_service_get: "memory_service_get";
                            memory_service_update: "memory_service_update";
                            memory_service_delete: "memory_service_delete";
                            memory_service_list: "memory_service_list";
                            memory_service_schema: "memory_service_schema";
                            memory_service_facets: "memory_service_facets";
                            context7_search: "context7_search";
                            grep_app_search: "grep_app_search";
                            web_search: "web_search";
                            fetch_content: "fetch_content";
                            product_prd_create: "product_prd_create";
                            product_prd_get: "product_prd_get";
                            product_prd_update: "product_prd_update";
                            product_prd_list: "product_prd_list";
                            product_task_comment: "product_task_comment";
                            session_todo_create: "session_todo_create";
                            session_todo_update: "session_todo_update";
                            session_todo_list: "session_todo_list";
                            session_todo_comment: "session_todo_comment";
                            session_todo_attach: "session_todo_attach";
                            product_generate_deck: "product_generate_deck";
                            sandbox_exec: "sandbox_exec";
                            loop_get_state: "loop_get_state";
                            loop_update_state: "loop_update_state";
                            coord_create_job: "coord_create_job";
                            coord_add_task: "coord_add_task";
                            coord_claim_task: "coord_claim_task";
                            coord_complete_task: "coord_complete_task";
                            coord_fail_task: "coord_fail_task";
                            coord_list_tasks: "coord_list_tasks";
                            coord_job_status: "coord_job_status";
                            coord_reserve_file: "coord_reserve_file";
                            coord_release_file: "coord_release_file";
                            coord_provide_contract: "coord_provide_contract";
                            coord_check_contract: "coord_check_contract";
                            coord_send_message: "coord_send_message";
                            coord_read_messages: "coord_read_messages";
                            coord_heartbeat: "coord_heartbeat";
                            coord_spawn_workers: "coord_spawn_workers";
                        }>, z.ZodString]>>>;
                        savedSkills: z.ZodDefault<z.ZodArray<z.ZodObject<{
                            skillId: z.ZodString;
                            repo: z.ZodString;
                            name: z.ZodOptional<z.ZodString>;
                            url: z.ZodOptional<z.ZodString>;
                            content: z.ZodOptional<z.ZodString>;
                        }, z.core.$strip>>>;
                        companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
                    }, z.core.$loose>>;
                }, z.core.$loose>>;
                lastActivityAt: z.ZodOptional<z.ZodString>;
                taskCount: z.ZodOptional<z.ZodNumber>;
                subAgentCount: z.ZodOptional<z.ZodNumber>;
                observerCount: z.ZodOptional<z.ZodNumber>;
                participantCount: z.ZodOptional<z.ZodNumber>;
            }, z.core.$loose>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    skills: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        skillId: z.ZodString;
                        repo: z.ZodString;
                        name: z.ZodOptional<z.ZodString>;
                        url: z.ZodOptional<z.ZodString>;
                        content: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>>;
                    enabledAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    visibility: z.ZodOptional<z.ZodEnum<{
                        private: "private";
                        organization: "organization";
                        collaborate: "collaborate";
                    }>>;
                    label: z.ZodOptional<z.ZodString>;
                    agent: z.ZodOptional<z.ZodString>;
                    defaultAgent: z.ZodOptional<z.ZodString>;
                    tags: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    skillBucketIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
                }, z.core.$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                sessionId: z.ZodString;
                label: z.ZodOptional<z.ZodString>;
                visibility: z.ZodOptional<z.ZodString>;
                tags: z.ZodOptional<z.ZodArray<z.ZodString>>;
                skills: z.ZodOptional<z.ZodArray<z.ZodUnknown>>;
                defaultAgent: z.ZodOptional<z.ZodNullable<z.ZodString>>;
                enabledAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
                metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
            }, z.core.$loose>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            label: string;
            tags: string[];
            task?: undefined;
            workflowMode?: undefined;
            mode?: undefined;
            sourceSessionId?: undefined;
            prompt?: undefined;
            slug?: undefined;
            displayName?: undefined;
            instructions?: undefined;
            tools?: undefined;
            serviceTools?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                sessionId: z.ZodString;
                status: z.ZodOptional<z.ZodString>;
            }, z.core.$loose>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                sessionId: z.ZodString;
                workflowMode: z.ZodEnum<{
                    standard: "standard";
                    loop: "loop";
                }>;
                loop: z.ZodNullable<z.ZodObject<{
                    status: z.ZodEnum<{
                        running: "running";
                        paused: "paused";
                        idle: "idle";
                        completed: "completed";
                        starting: "starting";
                        cancelled: "cancelled";
                        blocked: "blocked";
                        awaiting_input: "awaiting_input";
                    }>;
                    iteration: z.ZodNumber;
                    maxIterations: z.ZodOptional<z.ZodNumber>;
                    goal: z.ZodOptional<z.ZodString>;
                    summary: z.ZodOptional<z.ZodString>;
                    nextAction: z.ZodOptional<z.ZodString>;
                    loopId: z.ZodOptional<z.ZodString>;
                    startedAt: z.ZodOptional<z.ZodNumber>;
                    updatedAt: z.ZodOptional<z.ZodNumber>;
                    completedAt: z.ZodOptional<z.ZodNumber>;
                    lastCheckpointAt: z.ZodOptional<z.ZodNumber>;
                    autoContinue: z.ZodOptional<z.ZodBoolean>;
                    allowDetached: z.ZodOptional<z.ZodBoolean>;
                    activePrdKey: z.ZodOptional<z.ZodString>;
                    activePrdTaskId: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>>;
            }, z.core.$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                users: z.ZodArray<z.ZodObject<{
                    userId: z.ZodString;
                    displayName: z.ZodString;
                    email: z.ZodString;
                    provider: z.ZodString;
                    avatarUrl: z.ZodOptional<z.ZodString>;
                    lastLoginAt: z.ZodString;
                    lastSeenAt: z.ZodString;
                    createdAt: z.ZodString;
                }, z.core.$strip>>;
                total: z.ZodOptional<z.ZodNumber>;
                limit: z.ZodOptional<z.ZodNumber>;
                offset: z.ZodOptional<z.ZodNumber>;
            }, z.core.$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                sessionId: z.ZodString;
                entriesSource: z.ZodEnum<{
                    durable_stream: "durable_stream";
                    session_entries: "session_entries";
                    event_history: "event_history";
                    none: "none";
                }>;
                sourceCounts: z.ZodOptional<z.ZodObject<{
                    durableStream: z.ZodNumber;
                    sessionEntries: z.ZodNumber;
                    eventHistory: z.ZodNumber;
                }, z.core.$strip>>;
                entries: z.ZodArray<z.ZodUnknown>;
            }, z.core.$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                sessionId: z.ZodString;
                participants: z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    role: z.ZodString;
                    transport: z.ZodOptional<z.ZodString>;
                    agentRole: z.ZodOptional<z.ZodString>;
                    connectedAt: z.ZodOptional<z.ZodString>;
                    disconnectedAt: z.ZodOptional<z.ZodString>;
                    lastActivityAt: z.ZodOptional<z.ZodString>;
                    metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                }, z.core.$loose>>;
            }, z.core.$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                sessionId: z.ZodString;
                events: z.ZodArray<z.ZodObject<{
                    id: z.ZodNumber;
                    event: z.ZodString;
                    category: z.ZodOptional<z.ZodString>;
                    agent: z.ZodOptional<z.ZodString>;
                    taskId: z.ZodOptional<z.ZodString>;
                    payload: z.ZodOptional<z.ZodUnknown>;
                    occurredAt: z.ZodString;
                    ingestedAt: z.ZodOptional<z.ZodString>;
                }, z.core.$loose>>;
            }, z.core.$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                agents: z.ZodArray<z.ZodObject<{
                    slug: z.ZodString;
                    displayName: z.ZodString;
                    description: z.ZodOptional<z.ZodString>;
                    instructions: z.ZodString;
                    model: z.ZodOptional<z.ZodString>;
                    thinkingLevel: z.ZodOptional<z.ZodEnum<{
                        off: "off";
                        minimal: "minimal";
                        low: "low";
                        medium: "medium";
                        high: "high";
                        xhigh: "xhigh";
                    }>>;
                    headlessCompatible: z.ZodBoolean;
                    tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                        read: "read";
                        ls: "ls";
                        find: "find";
                        grep: "grep";
                        bash: "bash";
                        write: "write";
                        edit: "edit";
                    }>, z.ZodString]>>;
                    serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                        session_dashboard: "session_dashboard";
                        memory_service_search: "memory_service_search";
                        memory_service_store: "memory_service_store";
                        memory_service_get: "memory_service_get";
                        memory_service_update: "memory_service_update";
                        memory_service_delete: "memory_service_delete";
                        memory_service_list: "memory_service_list";
                        memory_service_schema: "memory_service_schema";
                        memory_service_facets: "memory_service_facets";
                        context7_search: "context7_search";
                        grep_app_search: "grep_app_search";
                        web_search: "web_search";
                        fetch_content: "fetch_content";
                        product_prd_create: "product_prd_create";
                        product_prd_get: "product_prd_get";
                        product_prd_update: "product_prd_update";
                        product_prd_list: "product_prd_list";
                        product_task_comment: "product_task_comment";
                        session_todo_create: "session_todo_create";
                        session_todo_update: "session_todo_update";
                        session_todo_list: "session_todo_list";
                        session_todo_comment: "session_todo_comment";
                        session_todo_attach: "session_todo_attach";
                        product_generate_deck: "product_generate_deck";
                        sandbox_exec: "sandbox_exec";
                        loop_get_state: "loop_get_state";
                        loop_update_state: "loop_update_state";
                        coord_create_job: "coord_create_job";
                        coord_add_task: "coord_add_task";
                        coord_claim_task: "coord_claim_task";
                        coord_complete_task: "coord_complete_task";
                        coord_fail_task: "coord_fail_task";
                        coord_list_tasks: "coord_list_tasks";
                        coord_job_status: "coord_job_status";
                        coord_reserve_file: "coord_reserve_file";
                        coord_release_file: "coord_release_file";
                        coord_provide_contract: "coord_provide_contract";
                        coord_check_contract: "coord_check_contract";
                        coord_send_message: "coord_send_message";
                        coord_read_messages: "coord_read_messages";
                        coord_heartbeat: "coord_heartbeat";
                        coord_spawn_workers: "coord_spawn_workers";
                    }>, z.ZodString]>>;
                    savedSkills: z.ZodArray<z.ZodObject<{
                        skillId: z.ZodString;
                        repo: z.ZodString;
                        name: z.ZodOptional<z.ZodString>;
                        url: z.ZodOptional<z.ZodString>;
                        content: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>;
                    companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
                    id: z.ZodString;
                    ownerUserId: z.ZodString;
                    lifecycle: z.ZodEnum<{
                        draft: "draft";
                        published: "published";
                        archived: "archived";
                    }>;
                    visibility: z.ZodEnum<{
                        org: "org";
                        private_draft: "private_draft";
                    }>;
                    createdAt: z.ZodString;
                    updatedAt: z.ZodString;
                    hasPublishedVersion: z.ZodBoolean;
                    hasUnpublishedChanges: z.ZodBoolean;
                    latestPublishedVersion: z.ZodOptional<z.ZodNumber>;
                    latestPublishedAt: z.ZodOptional<z.ZodString>;
                    published: z.ZodOptional<z.ZodObject<{
                        slug: z.ZodString;
                        displayName: z.ZodString;
                        description: z.ZodOptional<z.ZodString>;
                        instructions: z.ZodString;
                        model: z.ZodOptional<z.ZodString>;
                        thinkingLevel: z.ZodOptional<z.ZodEnum<{
                            off: "off";
                            minimal: "minimal";
                            low: "low";
                            medium: "medium";
                            high: "high";
                            xhigh: "xhigh";
                        }>>;
                        headlessCompatible: z.ZodBoolean;
                        tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                            read: "read";
                            ls: "ls";
                            find: "find";
                            grep: "grep";
                            bash: "bash";
                            write: "write";
                            edit: "edit";
                        }>, z.ZodString]>>;
                        serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                            session_dashboard: "session_dashboard";
                            memory_service_search: "memory_service_search";
                            memory_service_store: "memory_service_store";
                            memory_service_get: "memory_service_get";
                            memory_service_update: "memory_service_update";
                            memory_service_delete: "memory_service_delete";
                            memory_service_list: "memory_service_list";
                            memory_service_schema: "memory_service_schema";
                            memory_service_facets: "memory_service_facets";
                            context7_search: "context7_search";
                            grep_app_search: "grep_app_search";
                            web_search: "web_search";
                            fetch_content: "fetch_content";
                            product_prd_create: "product_prd_create";
                            product_prd_get: "product_prd_get";
                            product_prd_update: "product_prd_update";
                            product_prd_list: "product_prd_list";
                            product_task_comment: "product_task_comment";
                            session_todo_create: "session_todo_create";
                            session_todo_update: "session_todo_update";
                            session_todo_list: "session_todo_list";
                            session_todo_comment: "session_todo_comment";
                            session_todo_attach: "session_todo_attach";
                            product_generate_deck: "product_generate_deck";
                            sandbox_exec: "sandbox_exec";
                            loop_get_state: "loop_get_state";
                            loop_update_state: "loop_update_state";
                            coord_create_job: "coord_create_job";
                            coord_add_task: "coord_add_task";
                            coord_claim_task: "coord_claim_task";
                            coord_complete_task: "coord_complete_task";
                            coord_fail_task: "coord_fail_task";
                            coord_list_tasks: "coord_list_tasks";
                            coord_job_status: "coord_job_status";
                            coord_reserve_file: "coord_reserve_file";
                            coord_release_file: "coord_release_file";
                            coord_provide_contract: "coord_provide_contract";
                            coord_check_contract: "coord_check_contract";
                            coord_send_message: "coord_send_message";
                            coord_read_messages: "coord_read_messages";
                            coord_heartbeat: "coord_heartbeat";
                            coord_spawn_workers: "coord_spawn_workers";
                        }>, z.ZodString]>>;
                        savedSkills: z.ZodArray<z.ZodObject<{
                            skillId: z.ZodString;
                            repo: z.ZodString;
                            name: z.ZodOptional<z.ZodString>;
                            url: z.ZodOptional<z.ZodString>;
                            content: z.ZodOptional<z.ZodString>;
                        }, z.core.$strip>>;
                        companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
                        id: z.ZodString;
                        agentId: z.ZodString;
                        version: z.ZodNumber;
                        createdByUserId: z.ZodString;
                        createdAt: z.ZodString;
                    }, z.core.$loose>>;
                    draft: z.ZodOptional<z.ZodObject<{
                        slug: z.ZodString;
                        displayName: z.ZodString;
                        description: z.ZodOptional<z.ZodString>;
                        instructions: z.ZodString;
                        model: z.ZodOptional<z.ZodString>;
                        thinkingLevel: z.ZodOptional<z.ZodEnum<{
                            off: "off";
                            minimal: "minimal";
                            low: "low";
                            medium: "medium";
                            high: "high";
                            xhigh: "xhigh";
                        }>>;
                        headlessCompatible: z.ZodBoolean;
                        tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                            read: "read";
                            ls: "ls";
                            find: "find";
                            grep: "grep";
                            bash: "bash";
                            write: "write";
                            edit: "edit";
                        }>, z.ZodString]>>;
                        serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                            session_dashboard: "session_dashboard";
                            memory_service_search: "memory_service_search";
                            memory_service_store: "memory_service_store";
                            memory_service_get: "memory_service_get";
                            memory_service_update: "memory_service_update";
                            memory_service_delete: "memory_service_delete";
                            memory_service_list: "memory_service_list";
                            memory_service_schema: "memory_service_schema";
                            memory_service_facets: "memory_service_facets";
                            context7_search: "context7_search";
                            grep_app_search: "grep_app_search";
                            web_search: "web_search";
                            fetch_content: "fetch_content";
                            product_prd_create: "product_prd_create";
                            product_prd_get: "product_prd_get";
                            product_prd_update: "product_prd_update";
                            product_prd_list: "product_prd_list";
                            product_task_comment: "product_task_comment";
                            session_todo_create: "session_todo_create";
                            session_todo_update: "session_todo_update";
                            session_todo_list: "session_todo_list";
                            session_todo_comment: "session_todo_comment";
                            session_todo_attach: "session_todo_attach";
                            product_generate_deck: "product_generate_deck";
                            sandbox_exec: "sandbox_exec";
                            loop_get_state: "loop_get_state";
                            loop_update_state: "loop_update_state";
                            coord_create_job: "coord_create_job";
                            coord_add_task: "coord_add_task";
                            coord_claim_task: "coord_claim_task";
                            coord_complete_task: "coord_complete_task";
                            coord_fail_task: "coord_fail_task";
                            coord_list_tasks: "coord_list_tasks";
                            coord_job_status: "coord_job_status";
                            coord_reserve_file: "coord_reserve_file";
                            coord_release_file: "coord_release_file";
                            coord_provide_contract: "coord_provide_contract";
                            coord_check_contract: "coord_check_contract";
                            coord_send_message: "coord_send_message";
                            coord_read_messages: "coord_read_messages";
                            coord_heartbeat: "coord_heartbeat";
                            coord_spawn_workers: "coord_spawn_workers";
                        }>, z.ZodString]>>;
                        savedSkills: z.ZodArray<z.ZodObject<{
                            skillId: z.ZodString;
                            repo: z.ZodString;
                            name: z.ZodOptional<z.ZodString>;
                            url: z.ZodOptional<z.ZodString>;
                            content: z.ZodOptional<z.ZodString>;
                        }, z.core.$strip>>;
                        companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
                    }, z.core.$loose>>;
                }, z.core.$loose>>;
            }, z.core.$loose>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    slug: z.ZodString;
                    displayName: z.ZodString;
                    description: z.ZodOptional<z.ZodString>;
                    instructions: z.ZodString;
                    model: z.ZodOptional<z.ZodString>;
                    thinkingLevel: z.ZodOptional<z.ZodEnum<{
                        off: "off";
                        minimal: "minimal";
                        low: "low";
                        medium: "medium";
                        high: "high";
                        xhigh: "xhigh";
                    }>>;
                    headlessCompatible: z.ZodOptional<z.ZodBoolean>;
                    tools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
                        read: "read";
                        ls: "ls";
                        find: "find";
                        grep: "grep";
                        bash: "bash";
                        write: "write";
                        edit: "edit";
                    }>>>;
                    serviceTools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
                        session_dashboard: "session_dashboard";
                        memory_service_search: "memory_service_search";
                        memory_service_store: "memory_service_store";
                        memory_service_get: "memory_service_get";
                        memory_service_update: "memory_service_update";
                        memory_service_delete: "memory_service_delete";
                        memory_service_list: "memory_service_list";
                        memory_service_schema: "memory_service_schema";
                        memory_service_facets: "memory_service_facets";
                        context7_search: "context7_search";
                        grep_app_search: "grep_app_search";
                        web_search: "web_search";
                        fetch_content: "fetch_content";
                        product_prd_create: "product_prd_create";
                        product_prd_get: "product_prd_get";
                        product_prd_update: "product_prd_update";
                        product_prd_list: "product_prd_list";
                        product_task_comment: "product_task_comment";
                        session_todo_create: "session_todo_create";
                        session_todo_update: "session_todo_update";
                        session_todo_list: "session_todo_list";
                        session_todo_comment: "session_todo_comment";
                        session_todo_attach: "session_todo_attach";
                        product_generate_deck: "product_generate_deck";
                        sandbox_exec: "sandbox_exec";
                        loop_get_state: "loop_get_state";
                        loop_update_state: "loop_update_state";
                        coord_create_job: "coord_create_job";
                        coord_add_task: "coord_add_task";
                        coord_claim_task: "coord_claim_task";
                        coord_complete_task: "coord_complete_task";
                        coord_fail_task: "coord_fail_task";
                        coord_list_tasks: "coord_list_tasks";
                        coord_job_status: "coord_job_status";
                        coord_reserve_file: "coord_reserve_file";
                        coord_release_file: "coord_release_file";
                        coord_provide_contract: "coord_provide_contract";
                        coord_check_contract: "coord_check_contract";
                        coord_send_message: "coord_send_message";
                        coord_read_messages: "coord_read_messages";
                        coord_heartbeat: "coord_heartbeat";
                        coord_spawn_workers: "coord_spawn_workers";
                    }>>>;
                    savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    companionAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
                }, z.core.$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            slug: string;
            displayName: string;
            instructions: string;
            tools: string[];
            serviceTools: string[];
            task?: undefined;
            workflowMode?: undefined;
            mode?: undefined;
            sourceSessionId?: undefined;
            label?: undefined;
            prompt?: undefined;
            tags?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    slug: z.ZodOptional<z.ZodString>;
                    displayName: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
                    instructions: z.ZodOptional<z.ZodString>;
                    model: z.ZodOptional<z.ZodNullable<z.ZodString>>;
                    thinkingLevel: z.ZodOptional<z.ZodNullable<z.ZodEnum<{
                        off: "off";
                        minimal: "minimal";
                        low: "low";
                        medium: "medium";
                        high: "high";
                        xhigh: "xhigh";
                    }>>>;
                    headlessCompatible: z.ZodOptional<z.ZodBoolean>;
                    tools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
                        read: "read";
                        ls: "ls";
                        find: "find";
                        grep: "grep";
                        bash: "bash";
                        write: "write";
                        edit: "edit";
                    }>>>;
                    serviceTools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
                        session_dashboard: "session_dashboard";
                        memory_service_search: "memory_service_search";
                        memory_service_store: "memory_service_store";
                        memory_service_get: "memory_service_get";
                        memory_service_update: "memory_service_update";
                        memory_service_delete: "memory_service_delete";
                        memory_service_list: "memory_service_list";
                        memory_service_schema: "memory_service_schema";
                        memory_service_facets: "memory_service_facets";
                        context7_search: "context7_search";
                        grep_app_search: "grep_app_search";
                        web_search: "web_search";
                        fetch_content: "fetch_content";
                        product_prd_create: "product_prd_create";
                        product_prd_get: "product_prd_get";
                        product_prd_update: "product_prd_update";
                        product_prd_list: "product_prd_list";
                        product_task_comment: "product_task_comment";
                        session_todo_create: "session_todo_create";
                        session_todo_update: "session_todo_update";
                        session_todo_list: "session_todo_list";
                        session_todo_comment: "session_todo_comment";
                        session_todo_attach: "session_todo_attach";
                        product_generate_deck: "product_generate_deck";
                        sandbox_exec: "sandbox_exec";
                        loop_get_state: "loop_get_state";
                        loop_update_state: "loop_update_state";
                        coord_create_job: "coord_create_job";
                        coord_add_task: "coord_add_task";
                        coord_claim_task: "coord_claim_task";
                        coord_complete_task: "coord_complete_task";
                        coord_fail_task: "coord_fail_task";
                        coord_list_tasks: "coord_list_tasks";
                        coord_job_status: "coord_job_status";
                        coord_reserve_file: "coord_reserve_file";
                        coord_release_file: "coord_release_file";
                        coord_provide_contract: "coord_provide_contract";
                        coord_check_contract: "coord_check_contract";
                        coord_send_message: "coord_send_message";
                        coord_read_messages: "coord_read_messages";
                        coord_heartbeat: "coord_heartbeat";
                        coord_spawn_workers: "coord_spawn_workers";
                    }>>>;
                    savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
                    companionAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
                }, z.core.$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            displayName: string;
            task?: undefined;
            workflowMode?: undefined;
            mode?: undefined;
            sourceSessionId?: undefined;
            label?: undefined;
            prompt?: undefined;
            tags?: undefined;
            slug?: undefined;
            instructions?: undefined;
            tools?: undefined;
            serviceTools?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                versions: z.ZodArray<z.ZodObject<{
                    slug: z.ZodString;
                    displayName: z.ZodString;
                    description: z.ZodOptional<z.ZodString>;
                    instructions: z.ZodString;
                    model: z.ZodOptional<z.ZodString>;
                    thinkingLevel: z.ZodOptional<z.ZodEnum<{
                        off: "off";
                        minimal: "minimal";
                        low: "low";
                        medium: "medium";
                        high: "high";
                        xhigh: "xhigh";
                    }>>;
                    headlessCompatible: z.ZodBoolean;
                    tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                        read: "read";
                        ls: "ls";
                        find: "find";
                        grep: "grep";
                        bash: "bash";
                        write: "write";
                        edit: "edit";
                    }>, z.ZodString]>>;
                    serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                        session_dashboard: "session_dashboard";
                        memory_service_search: "memory_service_search";
                        memory_service_store: "memory_service_store";
                        memory_service_get: "memory_service_get";
                        memory_service_update: "memory_service_update";
                        memory_service_delete: "memory_service_delete";
                        memory_service_list: "memory_service_list";
                        memory_service_schema: "memory_service_schema";
                        memory_service_facets: "memory_service_facets";
                        context7_search: "context7_search";
                        grep_app_search: "grep_app_search";
                        web_search: "web_search";
                        fetch_content: "fetch_content";
                        product_prd_create: "product_prd_create";
                        product_prd_get: "product_prd_get";
                        product_prd_update: "product_prd_update";
                        product_prd_list: "product_prd_list";
                        product_task_comment: "product_task_comment";
                        session_todo_create: "session_todo_create";
                        session_todo_update: "session_todo_update";
                        session_todo_list: "session_todo_list";
                        session_todo_comment: "session_todo_comment";
                        session_todo_attach: "session_todo_attach";
                        product_generate_deck: "product_generate_deck";
                        sandbox_exec: "sandbox_exec";
                        loop_get_state: "loop_get_state";
                        loop_update_state: "loop_update_state";
                        coord_create_job: "coord_create_job";
                        coord_add_task: "coord_add_task";
                        coord_claim_task: "coord_claim_task";
                        coord_complete_task: "coord_complete_task";
                        coord_fail_task: "coord_fail_task";
                        coord_list_tasks: "coord_list_tasks";
                        coord_job_status: "coord_job_status";
                        coord_reserve_file: "coord_reserve_file";
                        coord_release_file: "coord_release_file";
                        coord_provide_contract: "coord_provide_contract";
                        coord_check_contract: "coord_check_contract";
                        coord_send_message: "coord_send_message";
                        coord_read_messages: "coord_read_messages";
                        coord_heartbeat: "coord_heartbeat";
                        coord_spawn_workers: "coord_spawn_workers";
                    }>, z.ZodString]>>;
                    savedSkills: z.ZodArray<z.ZodObject<{
                        skillId: z.ZodString;
                        repo: z.ZodString;
                        name: z.ZodOptional<z.ZodString>;
                        url: z.ZodOptional<z.ZodString>;
                        content: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>;
                    companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
                    id: z.ZodString;
                    agentId: z.ZodString;
                    version: z.ZodNumber;
                    createdByUserId: z.ZodString;
                    createdAt: z.ZodString;
                }, z.core.$loose>>;
            }, z.core.$loose>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=api-reference.d.ts.map