import { z } from 'zod/v4';
import { type APIClient } from '@agentuity/api';
export declare const DiscoverCoderUrlDataSchema: z.ZodObject<{
    url: z.ZodString;
}, z.core.$strip>;
/**
 * Discovers the org-specific Coder URL.
 *
 * Calls `GET /coder` on the Catalyst API. The org is resolved server-side
 * from the API key's auth context (not via query parameters).
 */
export declare function discoverUrl(client: APIClient): Promise<string>;
//# sourceMappingURL=discover.d.ts.map