import { z } from 'zod/v4';
import { CoderLoopStateResponseSchema } from "./types.js";
export const CoderGetLoopStateParamsSchema = z
    .object({
    sessionId: z.string().describe('Coder session identifier'),
    orgId: z.string().optional().describe('Optional org id for CLI auth context'),
})
    .describe('Parameters for retrieving loop state');
export async function coderGetLoopState(client, params) {
    const path = `/hub/session/${encodeURIComponent(params.sessionId)}/loop`;
    return client.get(path, CoderLoopStateResponseSchema);
}
//# sourceMappingURL=loop-state.js.map