import { z } from 'zod/v4';
import { type APIClient } from '@agentuity/api';
import { type CoderSessionEventHistory, type CoderSessionParticipants, type CoderSessionReplay } from './types.ts';
export declare const CoderGetSessionReplayParamsSchema: z.ZodObject<{
    sessionId: z.ZodString;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderGetSessionReplayParams = z.infer<typeof CoderGetSessionReplayParamsSchema>;
export declare const CoderListParticipantsParamsSchema: z.ZodObject<{
    sessionId: z.ZodString;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderListParticipantsParams = z.infer<typeof CoderListParticipantsParamsSchema>;
export declare const CoderListEventHistoryParamsSchema: z.ZodObject<{
    sessionId: z.ZodString;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderListEventHistoryParams = z.infer<typeof CoderListEventHistoryParamsSchema>;
export declare function coderGetReplay(client: APIClient, params: CoderGetSessionReplayParams): Promise<CoderSessionReplay>;
export declare function coderListParticipants(client: APIClient, params: CoderListParticipantsParams): Promise<CoderSessionParticipants>;
export declare function coderListEventHistory(client: APIClient, params: CoderListEventHistoryParams): Promise<CoderSessionEventHistory>;
//# sourceMappingURL=session-data.d.ts.map