import { z } from 'zod/v4';
import { type APIClient } from '@agentuity/api';
import { type CoderListUsersParams, type CoderListUsersResponse } from './types.ts';
export declare const CoderListUsersParamsWithOrgSchema: z.ZodObject<{
    search: z.ZodOptional<z.ZodString>;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderListUsersParamsWithOrg = z.infer<typeof CoderListUsersParamsWithOrgSchema>;
export declare function coderListUsers(client: APIClient, params?: CoderListUsersParams): Promise<CoderListUsersResponse>;
//# sourceMappingURL=users.d.ts.map