import { type APIClient } from '@agentuity/api';
import { type CoderGitHubAccountListResponse, type CoderGitHubRepositoryListResponse } from './types.ts';
/**
 * Lists GitHub accounts available via the caller's GitHub App installations.
 */
export declare function coderListGitHubAccounts(client: APIClient): Promise<CoderGitHubAccountListResponse>;
/**
 * Lists repositories accessible under a specific GitHub account.
 */
export declare function coderListGitHubRepos(client: APIClient, params: {
    accountId: string;
}): Promise<CoderGitHubRepositoryListResponse>;
//# sourceMappingURL=github.d.ts.map